@@ -1,3 +1,4 @@
+from github_poster.loader.bbdc_loader import BBDCLoader
 from github_poster.loader.bilibili_loader import BilibiliLoader
 from github_poster.loader.cichang_loader import CiChangLoader
 from github_poster.loader.dota2_loader import Dota2Loader
@@ -13,6 +14,7 @@ from github_poster.loader.json_loader import JsonLoader
 from github_poster.loader.kindle_loader import KindleLoader
 from github_poster.loader.leetcode_loader import LeetcodeLoader
 from github_poster.loader.multiple_loader import MutipleLoader
+from github_poster.loader.notion_loader import NotionLoader
 from github_poster.loader.nrc_loader import NRCLoader
 from github_poster.loader.ns_loader import NSLoader
 from github_poster.loader.shanbay_loader import ShanBayLoader
@@ -23,6 +25,7 @@ from github_poster.loader.wakatime_loader import WakaTimeLoader
 from github_poster.loader.youtube_loader import YouTubeLoader
 
 LOADER_DICT = {
+    "bbdc": BBDCLoader,
     "duolingo": DuolingoLoader,
     "shanbay": ShanBayLoader,
     "strava": StravaLoader,
@@ -41,6 +44,7 @@ LOADER_DICT = {
     "dota2": Dota2Loader,
     "multiple": MutipleLoader,
     "nike": NRCLoader,
+    "notion": NotionLoader,
     "garmin": GarminLoader,
     "forest": ForestLoader,
     "json": JsonLoader,
@@ -66,6 +70,7 @@ __all__ = (
     "WakaTimeLoader",
     "YouTubeLoader",
     "MutipleLoader",
+    "NotionLoader",
     "NRCLoader",
     "LOADER_DICT",
     "ForestLoader",
@@ -73,4 +78,5 @@ __all__ = (
     "JsonLoader",
     "JikeLoader",
     "SummaryLoader",
+    "BBDCLoader",
 )
