@@ -1,4 +1,3 @@
-import re
 from collections import namedtuple
 
 # China timezone if you are from others please change this
@@ -105,52 +104,9 @@ FOREST_CLAENDAR_URL = (
 JIKE_GRAPHQL_URL = "https://web-api.okjike.com/api/graphql"
 JIKE_PERSON_URL = "https://web.okjike.com/u/{user_id}"
 
-# argument dict
-ARGUMENT_DICT = {
-    "strava": [],
-    "shanbay": [],
-    "duolingo": [
-        {
-            "argument": "--duolingo_user_name",
-            "dest": "duolingo_user_name",
-            "type": str,
-            "help": "duolingo user name",
-            "required": True,
-        },
-        {
-            "argument": "--duolingo_password",
-            "dest": "duolingo_password",
-            "type": str,
-            "help": "duolingo password",
-            "required": True,
-        },
-    ],
-    "cichang": [],
-    "switch": [],
-    "gpx": [],
-    "github": [
-        {
-            "argument": "--github_user_name",
-            "dest": "github_user_name",
-            "type": str,
-            "required": True,
-            "help": "GitHub user name",
-        }
-    ],
-    "leetcode": [],
-    "bilibili": [
-        {
-            "argument": "--bilibili_cookie",
-            "dest": "bilibili_cookie",
-            "type": str,
-            "required": True,
-            "help": "The cookie for the bilibili website(XHR)",
-        }
-    ],
-    "kindle": [],
-    "wakatime": [],
-    "dota2": [],
-    "nike": [],
-    "forest": [],
-    "jike": [],
-}
+# bbdc
+BBDC_API_URL = "https://learnywhere.cn/bb/dashboard/profile/search?userId={user_id}"
+
+# Notion
+NOTION_API_URL = "https://api.notion.com/v1/databases/{database_id}/query"
+NOTION_API_VERSION = "2021-08-16"
