@@ -25,8 +25,8 @@ class MutipleLoader(BaseLoader):
             required=True,
             help="All types you want to generate summary, split by comma",
         )
-        for l in cls.parser_loader_list:
-            l.add_loader_arguments(parser, optional)
+        for loader in cls.parser_loader_list:
+            loader.add_loader_arguments(parser, optional)
 
     def get_api_data(self):
         pass
